#include <ast/statements/SingleStatement.h>
#include <ast/Option.h>
#include <ast/Param.h>
#include <ast/Arg.h>
#include <abstraction/common/AlgorithmHelper.h>

namespace cli {

SingleStatement::SingleStatement ( std::unique_ptr < Arg > name, ext::vector < std::unique_ptr < Param > > params, ext::vector < std::unique_ptr < Option > > options ) : m_name ( std::move ( name ) ), m_params ( std::move ( params ) ), m_options ( std::move ( options ) ) {
	for ( const std::unique_ptr < Option > & option : m_options ) {
		option->eval ( * this );
	}
}

std::shared_ptr < abstraction::OperationAbstraction > SingleStatement::translateAndEval ( const std::shared_ptr < abstraction::OperationAbstraction > & prev, Environment & environment ) const {
	ext::vector < std::shared_ptr < abstraction::OperationAbstraction > > params;
	for ( const std::unique_ptr < Param > & param : m_params ) {
		params.push_back ( param->translateAndEval ( prev, environment ) );
	}

	std::vector < bool > moves;
	for ( const std::unique_ptr < Param > & param : m_params ) {
		moves.push_back ( param->getMove ( ) );
	}

	std::string name = m_name->eval ( environment );

	return abstraction::AlgorithmHelper::eval ( name, params, moves );
}

} /* namespace cli */
